# rainbownum
Program used to generate colorings and the anti-Schur numbers for a given equation.

An anti-Schur number, denoted aS([n], k, [a], b), is defined as the smallest number of colors r such that every coloring of [n] if guaranteed to have a rainbow sum to the equations a_1x_1 + a_2x_2 + ... + a_kx_k = b.

https://pypi.org/project/rainbownum/#history

Install notes:

pip install rainbownum

pip install --upgrade rainbownum
